pub trait DecodeTrace<'de, M, A>: Sizedwhere
A: Allocator,{
// Required method
fn trace_decode<D>(decoder: D) -> Result<Self, D::Error>
where D: Decoder<'de, Mode = M, Allocator = A>;
}Expand description
Trait governing how types are decoded specifically for tracing.
This is used for types where some extra bounds might be necessary to trace a
container such as a HashMap<K, V> where K would have to implement
fmt::Display.
Required Methods
Sourcefn trace_decode<D>(decoder: D) -> Result<Self, D::Error>where
D: Decoder<'de, Mode = M, Allocator = A>,
fn trace_decode<D>(decoder: D) -> Result<Self, D::Error>where
D: Decoder<'de, Mode = M, Allocator = A>,
Decode the given input.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<'de, K, V, A, M, S> DecodeTrace<'de, M, A> for HashMap<K, V, S>
Available on crate feature std only.
impl<'de, K, V, A, M, S> DecodeTrace<'de, M, A> for HashMap<K, V, S>
Available on crate feature
std only.