pub trait EncodeTrace<M> {
// Required method
fn trace_encode<E>(&self, encoder: E) -> Result<(), E::Error>
where E: Encoder<Mode = M>;
// Provided method
fn size_hint(&self) -> Option<usize> { ... }
}Expand description
Trait governing how types are encoded specifically for tracing.
This is used for types where some extra bounds might be necessary to trace a
container such as a HashMap<K, V> where K would have to implement
fmt::Display.
Required Methods
Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<'de, M, K, V, S> EncodeTrace<M> for HashMap<K, V, S>
Available on crate feature std only.
impl<'de, M, K, V, S> EncodeTrace<M> for HashMap<K, V, S>
Available on crate feature
std only.